export declare type FunctionRuntimeContributorFactory = (context: any) => Contributor<FunctionRuntimeParameters> & FunctionRuntimeLifecycleManager;
export declare type FunctionRuntimeParameters = Pick<FunctionParameters, 'runtime'>;
export declare type FunctionTemplateContributorFactory = ContributorFactory<FunctionTemplateParameters>;
export declare type FunctionTemplateParameters = Pick<FunctionParameters, 'dependsOn' | 'functionTemplate' | 'triggerEventSourceMappings'>;
export declare type ContributorFactory<T extends Partial<FunctionParameters>> = (context: any) => Contributor<T>;
export interface Contributor<T extends Partial<FunctionParameters>> {
    contribute(request: ContributionRequest): Promise<T>;
}
export interface FunctionRuntimeLifecycleManager {
    checkDependencies(runtimeValue: string): Promise<CheckDependenciesResult>;
    package(request: PackageRequest): Promise<PackageResult>;
    build(request: BuildRequest): Promise<BuildResult>;
    invoke(request: InvocationRequest): Promise<any>;
}
export declare type ContributionRequest = {
    selection: string;
    contributionContext: {
        runtime: FunctionRuntime;
        functionName: string;
        resourceName: string;
    };
};
export declare type InvocationRequest = {
    srcRoot: string;
    env: string;
    runtime: string;
    handler: string;
    event: string;
    lastBuildTimestamp?: Date;
    envVars?: {
        [key: string]: string;
    };
};
export declare type BuildRequest = {
    env: string;
    srcRoot: string;
    runtime: string;
    legacyBuildHookParams?: {
        projectRoot: string;
        resourceName: string;
    };
    lastBuildTimestamp?: Date;
};
export declare type PackageRequest = {
    env: string;
    srcRoot: string;
    dstFilename: string;
    runtime: string;
    lastBuildTimestamp: Date;
    lastPackageTimestamp?: Date;
};
export declare type BuildResult = {
    rebuilt: boolean;
};
export declare type PackageResult = {
    packageHash?: string;
};
export declare type CheckDependenciesResult = {
    hasRequiredDependencies: boolean;
    errorMessage?: string;
};
export declare type FunctionParameters = {
    providerContext: ProviderContext;
    cloudResourceTemplatePath: string;
    resourceName: string;
    functionName: string;
    runtime: FunctionRuntime;
    roleName: string;
    dependsOn?: FunctionDependency[];
    functionTemplate?: FunctionTemplate;
    categoryPolicies?: object[];
    skipEdit?: boolean;
    parametersFileObj?: object;
    resourceProperties?: object[];
    triggerEventSourceMappings?: any;
    topLevelComment?: string;
    runtimePluginId: string;
    cloudwatchRule?: string;
};
export interface FunctionTriggerParameters {
    trigger: boolean;
    key: string;
    modules: any[];
    parentResource: string;
    functionName: string;
    resourceName: string;
    parentStack: string;
    triggerEnvs: any;
    triggerIndexPath: string;
    triggerPackagePath: string;
    triggerDir: string;
    roleName: string;
    triggerTemplate: string;
    triggerEventPath: string;
    skipEdit: boolean;
    functionTemplate?: FunctionTemplate;
    cloudResourceTemplatePath?: string;
}
export interface ProviderContext {
    provider: string;
    service: string;
    projectName: string;
}
export interface FunctionRuntime {
    name: string;
    value: string;
    cloudTemplateValue: string;
    defaultHandler: string;
}
export interface FunctionTemplate {
    handler?: string;
    parameters?: any;
    sourceRoot: string;
    sourceFiles: string[];
    destMap?: {
        [name: string]: string;
    };
    defaultEditorFile?: string;
}
export interface FunctionDependency {
    category: string;
    resourceName: string;
    attributes: string[];
    attributeEnvMap?: {
        [name: string]: string;
    };
}
interface FunctionContributorCondition {
    provider?: string;
    service?: string;
    runtime?: string | Array<string>;
}
export declare type FunctionTemplateCondition = FunctionContributorCondition;
export declare type FunctionRuntimeCondition = Pick<FunctionContributorCondition, 'provider' | 'service'>;
export interface FunctionBreadcrumbs {
    pluginId: string;
    functionRuntime: string;
    useLegacyBuild: boolean;
    defaultEditorFile: string;
    scripts?: Record<'build' & 'package', FunctionScript>;
}
export interface FunctionScript {
    type: 'file' | 'inline';
    value: string;
}
export {};
//# sourceMappingURL=index.d.ts.map